==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_fields/STATUSCHANGETRIGGERSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour STATUSCHANGETRIGGERSID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="STATUSCHANGETRIGGERSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OLDWOSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NEWWOSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STATUSCHANGETRIGGERSID_Type", propOrder = {
    "oldwostatus",
    "newwostatus",
    "wotype"
})
public class STATUSCHANGETRIGGERSID_Type {

    @XmlElement(name = "OLDWOSTATUS", required = true)
    protected String oldwostatus;
    @XmlElement(name = "NEWWOSTATUS", required = true)
    protected String newwostatus;
    @XmlElement(name = "WOTYPE", required = true)
    protected TYPE_Type wotype;

    /**
     * Obtient la valeur de la propriété oldwostatus.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOLDWOSTATUS() {
        return oldwostatus;
    }

    /**
     * Définit la valeur de la propriété oldwostatus.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOLDWOSTATUS(String value) {
        this.oldwostatus = value;
    }

    /**
     * Obtient la valeur de la propriété newwostatus.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNEWWOSTATUS() {
        return newwostatus;
    }

    /**
     * Définit la valeur de la propriété newwostatus.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNEWWOSTATUS(String value) {
        this.newwostatus = value;
    }

    /**
     * Obtient la valeur de la propriété wotype.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWOTYPE() {
        return wotype;
    }

    /**
     * Définit la valeur de la propriété wotype.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWOTYPE(TYPE_Type value) {
        this.wotype = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/STATUSCHANGETRIGGERSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for STATUSCHANGETRIGGERSID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="STATUSCHANGETRIGGERSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OLDWOSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NEWWOSTATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOTYPE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STATUSCHANGETRIGGERSID_Type", propOrder = {
    "oldwostatus",
    "newwostatus",
    "wotype"
})
public class STATUSCHANGETRIGGERSID_Type {

    @XmlElement(name = "OLDWOSTATUS", required = true)
    protected String oldwostatus;
    @XmlElement(name = "NEWWOSTATUS", required = true)
    protected String newwostatus;
    @XmlElement(name = "WOTYPE", required = true)
    protected TYPE_Type wotype;

    /**
     * Gets the value of the oldwostatus property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOLDWOSTATUS() {
        return oldwostatus;
    }

    /**
     * Sets the value of the oldwostatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOLDWOSTATUS(String value) {
        this.oldwostatus = value;
    }

    /**
     * Gets the value of the newwostatus property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNEWWOSTATUS() {
        return newwostatus;
    }

    /**
     * Sets the value of the newwostatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNEWWOSTATUS(String value) {
        this.newwostatus = value;
    }

    /**
     * Gets the value of the wotype property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getWOTYPE() {
        return wotype;
    }

    /**
     * Sets the value of the wotype property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setWOTYPE(TYPE_Type value) {
        this.wotype = value;
    }

}
